Learn R Programming

crsra (version 0.2.3)

crsra_anonymize: Anonymizes ID variables (such as Partner hashed user ids) throughout the data set. The function is based on the function digest from the package digest.

Description

This function will still keep the relationship between tables, i.e. it will change a specific id across all tables to the same id.

Usage

crsra_anonymize(all_tables,
  col_to_mask = attributes(all_tables)$partner_user_id, algorithm = "crc32")

Arguments

all_tables
col_to_mask

The name of id column to mask.

algorithm

The algorithms to be used for anonymization; for currently available choices, see digest.

Value

A list that contains all the tables within each course.

Examples

Run this code
# NOT RUN {
res = crsra_anonymize(example_course_import,
col_to_mask = "jhu_user_id",
algorithm = "crc32")
# }

Run the code above in your browser using DataLab