Learn R Programming

crsra (version 0.2.3)

crsra_gradesummary: The average course grade across different groups

Description

The average course grade across different groups

Usage

crsra_gradesummary(all_tables, groupby = c("total", "country", "language",
  "gender", "empstatus", "education", "stustatus"))

Arguments

all_tables
groupby

A character string indicating the how to break down grades. The default is set to total and returns the grade summary for each course. Other values are gender (for grouping by gender), education (for grouping by education level), stustatus (for grouping by student status), empstatus (for grouping by employment status), and country (for grouping by country). Note that this grouping uses the entries in the table users that is not fully populated so by grouping you lose some observations.

Value

A table which indicates the average grade across specified groups for each course

Examples

Run this code
# NOT RUN {
crsra_gradesummary(example_course_import)
crsra_gradesummary(example_course_import, groupby = "education")
# }

Run the code above in your browser using DataLab