powered by
Time that took each learner (in days) to finish a course
crsra_timetofinish(all_tables)
A list from crsra_import_course or crsra_import
crsra_import_course
crsra_import
A table containing hashed_user_ids with a column indicating the time (in days) that took each user to complete a course. The time is calculated as the difference between the last and first activity in the a course.
hashed_user_id
# NOT RUN { crsra_timetofinish(example_course_import) # }
Run the code above in your browser using DataLab