crsra_anonymize: Anonymizes ID variables (such as Partner hashed user ids) throughout
the data set. The function is based on the function digest from the
package digest.
Description
This function will still keep the relationship between tables, i.e. it will
change a specific id across all tables to the same id.