A character string indicating the how to break down
grades. The default is set to total and returns the grade
summary for each course. Other values are gender (for
grouping by gender), education (for grouping by education
level), stustatus (for grouping by student status),
empstatus (for grouping by employment status), and
country (for grouping by country). Note that this
grouping uses the entries in the table users that is
not fully populated so by grouping you lose some observations.
Value
A table which indicates the average grade across specified
groups for each course