A character string indicating the how to break down learners
in each course. The default is set to roles and returns the
share of students in each category such as Learner, Not Enrolled,
Pre-Enrolled Learner, Mentor, Browser, and Instructor.
Other values are country (for grouping based on country),
language (for grouping based on language), gender
(for grouping by gender), education (for grouping by
education level), stustatus (for grouping by student status),
empstatus (for grouping by employment status), and country
(for grouping by country). Note that this grouping uses the entries
in the table users that is not fully populated so by grouping
you lose some observations.